"""
In-house Site Generator
"""

from typing import List

from . import simple


def main(*args: List[str]) -> int:
    if len(args) >= 3:
        simple.generate(args[1], args[2])
    return 0


if __name__ == "__main__":
    import sys
    sys.exit(main(*sys.argv))



"""
Simple, no configuration site generator module
"""

def generate(src_dir, dst_dir):
    print("Source dir `%s`" % src_dir)
    print("Destination dir `%s`" % dst_dir)

    # TODO: generate HTML for every .md file in src_dir and
    # place them in dst_dir



"""
Parsers module includes various parsing functions.
"""

import markdown as markdownlib
from pathlib import Path
from typing import Union

# vikilink buildurl https://python-markdown.github.io/extensions/wikilinks/#examples

def markdown_s(input: str) -> str:
    """
    Convert markdown to HTML
    """
    # NOTE(bora): Docs: https://python-markdown.github.io/sitemap.html
    return markdownlib.markdown(
        input,
        extensions=["fenced_code", "footnotes"])


def markdown(
    in_file: Union[str, Path],
    out_file: Union[str, Path]
) -> None:
    """
    Convert markdown file to HTML
    """
    with open(in_file, encoding="utf-8") as fp_in:
        with open(out_file, "w", encoding="utf-8") as fp_out:
            fp_out.write(markdown_s(fp_in.read()))




import setuptools
import sitegenlib 

try:
    with open("README.md", encoding="utf-8") as fp:
        LONG_DESCRIPTION = fp.read()
except IOError:
    LONG_DESCRIPTION = ""


if __name__ == "__main__":
    setuptools.setup(
        name="iwg",
        version=sitegenlib.VERSION,
        description="An in-house website generator",
        long_description=LONG_DESCRIPTION,
        long_description_content_type="text/markdown",
        author="Bora Ozdogan",
        author_email="boraozdogan99@gmail.com",
        url="http://github.com/bozdogan/iwg",
        license="MIT",
        packages=setuptools.find_packages(),
        install_requires=["pytoml", "markdown~=3.3.6"],
        extras_require={
            "dev": [
            ]
        },
        classifiers=[
            "Development Status :: 1 - Planning",
            "Environment :: Console",
            "Intended Audience :: Developers",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3.8",
            "Topic :: Software Development :: Code Generators",
        ],
    )
